@@ -647,9 +647,9 @@ class ConsumerThread(Thread):
                 if self.result_list[result_id]['state'] != ConsumerThread.FREE:
                     self.result_list[result_id]['result_message'] = message_data
                     self.result_list[result_id]['state'] = ConsumerThread.DONE
-            time.sleep(0.1)
-#      else:
-#        time.sleep(0.001)
+            else:
+                time.sleep(0.1)
+
 
 #===========================================================================
 class PublisherThread(Thread):
