@@ -78,27 +78,27 @@ class  QamTestCase(unittest.TestCase):
     #    self.foo = None
 
 
-    def long_non_load_test(self):
-        print 'long_non_load_test'
-        proxy = QAMProxy(hostname=self.amqp_hostname,
-                         port=self.amqp_port,
-                         username=self.amqp_user,
-                         password=self.amqp_pwd,
-                         vhost=self.amqp_vhost,
-                         server_id='testqamserver',
-                         client_id='testqamclient1',
-                         serializer='json'
-                         )
-
-        for i in range(3):
-            time.sleep(5)
-            a = i
-            b = 1
-            golden_device = a + b
-            result = proxy.add(a, b)
-            self.assertEqual(golden_device, result, "%d + %d must equal %d" % (a, b, golden_device))
-
-        proxy.close()
+#    def test_long_non_load_test(self):
+#        print 'long_non_load_test'
+#        proxy = QAMProxy(hostname=self.amqp_hostname,
+#                         port=self.amqp_port,
+#                         username=self.amqp_user,
+#                         password=self.amqp_pwd,
+#                         vhost=self.amqp_vhost,
+#                         server_id='testqamserver',
+#                         client_id='testqamclient1',
+#                         serializer='json'
+#                         )
+#
+#        for i in range(3):
+#            time.sleep(5)
+#            a = i
+#            b = 1
+#            golden_device = a + b
+#            result = proxy.add(a, b)
+#            self.assertEqual(golden_device, result, "%d + %d must equal %d" % (a, b, golden_device))
+#
+#        proxy.close()
 
     def test_basic_method_call(self):
         print 'test_basic_method_call'
